==> huaweicloudsdkiam-3.0.56-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/security_compliance.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SecurityCompliance:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'password_regex': 'str',
        'password_regex_description': 'str'
    }

    attribute_map = {
        'password_regex': 'password_regex',
        'password_regex_description': 'password_regex_description'
    }

    def __init__(self, password_regex=None, password_regex_description=None):
        """SecurityCompliance - a model defined in huaweicloud sdk"""
        
        

        self._password_regex = None
        self._password_regex_description = None
        self.discriminator = None

        self.password_regex = password_regex
        self.password_regex_description = password_regex_description

    @property
    def password_regex(self):
        """Gets the password_regex of this SecurityCompliance.

        密码强度策略的正则表达式。

        :return: The password_regex of this SecurityCompliance.
        :rtype: str
        """
        return self._password_regex

    @password_regex.setter
    def password_regex(self, password_regex):
        """Sets the password_regex of this SecurityCompliance.

        密码强度策略的正则表达式。

        :param password_regex: The password_regex of this SecurityCompliance.
        :type: str
        """
        self._password_regex = password_regex

    @property
    def password_regex_description(self):
        """Gets the password_regex_description of this SecurityCompliance.

        密码强度策略的描述。

        :return: The password_regex_description of this SecurityCompliance.
        :rtype: str
        """
        return self._password_regex_description

    @password_regex_description.setter
    def password_regex_description(self, password_regex_description):
        """Sets the password_regex_description of this SecurityCompliance.

        密码强度策略的描述。

        :param password_regex_description: The password_regex_description of this SecurityCompliance.
        :type: str
        """
        self._password_regex_description = password_regex_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityCompliance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.102-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/security_compliance.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SecurityCompliance:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'password_regex': 'str',
        'password_regex_description': 'str'
    }

    attribute_map = {
        'password_regex': 'password_regex',
        'password_regex_description': 'password_regex_description'
    }

    def __init__(self, password_regex=None, password_regex_description=None):
        """SecurityCompliance

        The model defined in huaweicloud sdk

        :param password_regex: 密码强度策略的正则表达式。
        :type password_regex: str
        :param password_regex_description: 密码强度策略的描述。
        :type password_regex_description: str
        """
        
        

        self._password_regex = None
        self._password_regex_description = None
        self.discriminator = None

        self.password_regex = password_regex
        self.password_regex_description = password_regex_description

    @property
    def password_regex(self):
        """Gets the password_regex of this SecurityCompliance.

        密码强度策略的正则表达式。

        :return: The password_regex of this SecurityCompliance.
        :rtype: str
        """
        return self._password_regex

    @password_regex.setter
    def password_regex(self, password_regex):
        """Sets the password_regex of this SecurityCompliance.

        密码强度策略的正则表达式。

        :param password_regex: The password_regex of this SecurityCompliance.
        :type password_regex: str
        """
        self._password_regex = password_regex

    @property
    def password_regex_description(self):
        """Gets the password_regex_description of this SecurityCompliance.

        密码强度策略的描述。

        :return: The password_regex_description of this SecurityCompliance.
        :rtype: str
        """
        return self._password_regex_description

    @password_regex_description.setter
    def password_regex_description(self, password_regex_description):
        """Sets the password_regex_description of this SecurityCompliance.

        密码强度策略的描述。

        :param password_regex_description: The password_regex_description of this SecurityCompliance.
        :type password_regex_description: str
        """
        self._password_regex_description = password_regex_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityCompliance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
